
# q-expansion of newform 1710.2.p.b, downloaded from the LMFDB on 02 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1710
weight = 2
poly_data = [1, 0, 96, 0, 892, 0, 1960, 0, 1858, 0, 880, 0, 212, 0, 24, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[5958, 3595, 70652, -99455, 203442, -166465, 231966, -84345, 122062, -11145, 31136, 2265, 3634, 615, 154, 35], 2320], [[0, -402, 0, -2743, 0, -4598, 0, -3369, 0, -1278, 0, -259, 0, -26, 0, -1], 40], [[7180, -12833, 112410, 12173, 232810, 103223, 212530, 120909, 102320, 59083, 25730, 13849, 3030, 1511, 130, 61], 2320], [[-5040, -9547, -91150, -49413, -245310, -92163, -278090, -86759, -151500, -42423, -40270, -10509, -4850, -1211, -210, -51], 2320], [[5040, -32863, 91150, -208507, 245310, -358847, 278090, -282161, 151500, -116547, 40270, -25531, 4850, -2719, 210, -109], 2320], [[-7180, 10483, -112410, 171267, -232810, 369907, -212530, 316311, -102320, 133207, -25730, 28871, -3030, 3019, -130, 119], 2320], [[5958, -31075, 70652, -137655, 203442, -289935, 231966, -285945, 122062, -139895, 31136, -34375, 3634, -3935, 154, -165], 2320], [[1041, -8855, 19504, -110340, 47429, -231035, 43722, -201535, 19229, -87815, 4272, -19690, 453, -2115, 18, -85], 1160], [[-1041, -8855, -19504, -110340, -47429, -231035, -43722, -201535, -19229, -87815, -4272, -19690, -453, -2115, -18, -85], 1160], [[-5958, -31075, -70652, -137655, -203442, -289935, -231966, -285945, -122062, -139895, -31136, -34375, -3634, -3935, -154, -165], 2320], [[-1888, -36525, 23738, -343295, 100528, -826715, 120224, -850665, 63048, -427325, 15814, -107055, 1816, -12415, 76, -525], 2320], [[1888, -36525, -23738, -343295, -100528, -826715, -120224, -850665, -63048, -427325, -15814, -107055, -1816, -12415, -76, -525], 2320], [[4548, -36525, -26518, -343295, -238608, -826715, -377964, -850665, -237468, -427325, -67874, -107055, -8496, -12415, -376, -525], 2320], [[3310, -43491, 2550, -558849, 69040, -1418809, 128870, -1487177, 87210, -756819, 26030, -191717, 3340, -22413, 150, -953], 2320], [[1150, -63521, 18710, -779529, -81540, -1880879, -194430, -1890247, -136390, -932449, -40570, -231097, -5160, -26643, -230, -1123], 2320]]

hecke_ring_character_values = [[191, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1027, [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1351, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, 1, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 1, 2, 1, 0, -1, 0, 1, 0, 0], [2, 0, 2, 0, -1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, -1, 0, 0, -1, 1, -1, 1, -1, 0, -1, 1, 0, 0], [1, 0, -1, 3, 0, -3, -1, 0, 0, 0, 0, 0, 0, 0, 0, -1], [0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, -1, -2, 3, 0, 0], [0, 2, 0, 0, 0, 0, 0, -1, 1, 1, 1, 2, 2, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, -4, -1, 0, -1, 1, 0, 0], [0, 2, 0, 0, 0, 0, 0, -1, 2, 2, 1, 0, 0, 0, 0, 0], [2, 0, -2, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, -1], [-2, 0, -2, 0, -2, -2, 0, 0, 0, 0, 0, 0, 0, 0, -2, 2], [0, 0, 0, 0, 0, 0, 0, 1, 4, 1, -1, 1, 1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -3, -1, 1, 3, -2, 1, 1, 0, 0], [-4, 0, -1, 0, -3, 1, 2, 0, 0, 0, 0, 0, 0, 0, -2, 2], [0, 1, 0, 0, 0, 0, 0, -1, -2, 2, -1, -2, -1, 2, 0, 0], [0, 4, 0, 0, 0, 0, 0, -4, -2, -2, 0, 1, 1, 0, 0, 0], [0, 0, 0, -3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0], [0, 0, 0, 0, 0, 0, 0, -3, 5, -5, 3, 3, -1, -2, 0, 0], [1, 0, -1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, -1, 1], [0, 0, 0, 0, 0, 0, 0, -1, 8, -8, 1, 0, 2, -2, 0, 0], [0, 2, 0, 0, 0, 0, 0, -1, 1, -3, 3, 1, 3, -2, 0, 0], [-3, 0, -2, 0, -1, 2, -1, 0, 0, 0, 0, 0, 0, 0, 1, -1], [0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 3, -3, -3, 3, 0, 0], [0, -1, 0, 0, 0, 0, 0, -1, 4, -6, 3, 4, 3, -2, 0, 0], [0, 0, 0, 0, 0, 0, 0, -1, -4, 4, 1, -3, -4, 7, 0, 0], [0, 3, 0, 0, 0, 0, 0, 3, -2, 3, 1, 2, -1, 4, 0, 0], [0, 2, 0, 0, 0, 0, 0, 2, 0, -2, 2, 0, 2, -4, 0, 0], [6, 0, 0, -2, -2, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 0, -2, 0, -5, -4, 1, 0, 0, 0, 0, 0, 0, 0, -4, 4], [-1, 0, -5, 0, -2, -1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1], [1, 0, -3, -2, 4, 3, -3, 0, 0, 0, 0, 0, 0, 0, -1, -1], [0, -2, 0, 0, 0, 0, 0, -1, -7, -7, -3, -1, -1, 0, 0, 0], [2, 0, 2, 0, -8, -6, 4, 0, 0, 0, 0, 0, 0, 0, -6, 4], [-5, 0, 5, -2, 0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 1, -2], [0, 4, 0, 0, 0, 0, 0, -2, 1, -2, 5, 1, 5, -3, 0, 0], [0, 3, 0, 0, 0, 0, 0, -2, 2, -2, 3, 0, -3, 1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 1, -4, 4, -1, -3, 5, -2, 0, 0], [0, -4, 0, 0, 0, 0, 0, 2, -3, -3, -2, -2, -2, 0, 0, 0], [6, 0, 0, -1, 4, 1, -4, 0, 0, 0, 0, 0, 0, 0, 5, -5], [0, -2, 0, 0, 0, 0, 0, -2, 10, -2, 2, -4, -2, 0, 0, 0], [-5, 0, -5, 0, 4, 6, -3, 0, 0, 0, 0, 0, 0, 0, 6, -1], [0, 0, -12, -3, 2, 2, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 2, 12, 12, 1, 1, 1, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, -1, -13, -1, 1, 3, -1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 7, -1, -1, -1, 1, 0, 0], [-4, 0, 6, -8, 2, 6, -4, 0, 0, 0, 0, 0, 0, 0, 4, 4], [-3, 0, 3, 2, 0, 2, 8, 0, 0, 0, 0, 0, 0, 0, -4, 8], [1, 0, 7, 0, -1, -2, -1, 0, 0, 0, 0, 0, 0, 0, -1, -1], [0, 2, 0, 0, 0, 0, 0, -1, 9, 9, 1, 1, 1, 0, 0, 0], [-11, 0, 2, -5, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 5, -5], [0, -3, 0, 0, 0, 0, 0, -3, 0, 9, -3, 0, -3, 6, 0, 0], [-12, 0, 12, -6, 0, 1, -3, 0, 0, 0, 0, 0, 0, 0, 5, -3], [0, 0, 0, 0, 0, 0, 0, 2, -8, 8, -2, 4, 0, -4, 0, 0], [0, 0, 0, -3, 4, 3, -4, 0, 0, 0, 0, 0, 0, 0, 7, -7], [2, 0, 2, 0, -2, -8, 0, 0, 0, 0, 0, 0, 0, 0, -8, 2], [0, -2, 0, 0, 0, 0, 0, -1, -2, -2, -3, 4, 4, 0, 0, 0], [-3, 0, 3, 4, 0, -7, 3, 0, 0, 0, 0, 0, 0, 0, 3, 3], [0, 0, 0, 0, 0, 0, 0, 5, -6, 5, -1, 1, 1, 4, 0, 0], [0, -2, 0, 0, 0, 0, 0, 4, 4, 4, 2, 4, 2, -6, 0, 0], [-7, 0, 3, 0, 3, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 1, -9, 0, 7, 4, 0, 0, 0, 0, 0, 0, 0, 2, 4], [0, -2, 0, 0, 0, 0, 0, 7, 1, 4, -1, 1, -1, -6, 0, 0], [0, 7, 0, 0, 0, 0, 0, -5, -2, -2, 2, 6, 6, 0, 0, 0], [0, -7, 0, 0, 0, 0, 0, 5, 0, 1, -7, 0, -7, 2, 0, 0], [6, 0, 6, 0, 8, -2, -6, 0, 0, 0, 0, 0, 0, 0, -2, -2], [4, 0, 8, 0, 4, 0, -4, 0, 0, 0, 0, 0, 0, 0, -4, -4], [13, 0, -13, 3, 0, 3, 2, 0, 0, 0, 0, 0, 0, 0, -6, 2], [-3, 0, -9, -2, -3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 3], [-16, 0, -16, 0, -4, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, -3, 0, 0, 0, 0, 0, 5, 6, 5, 2, -5, -2, 7, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 3, 2, -5, 0, 0], [0, -6, 0, 0, 0, 0, 0, -3, 0, -3, 0, -6, 0, -3, 0, 0], [-2, 0, 5, -4, 3, 5, -2, 0, 0, 0, 0, 0, 0, 0, 2, 2], [-3, 0, -3, 0, 0, -3, -5, 0, 0, 0, 0, 0, 0, 0, -3, 5], [0, -20, 0, 0, 0, 0, 0, 8, -7, -7, -12, -7, -7, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -6, -1, 1, 6, -3, 5, -2, 0, 0], [-6, 0, -5, -3, -2, 4, 3, 0, 0, 0, 0, 0, 0, 0, 6, 6], [0, -3, 0, 0, 0, 0, 0, -5, -11, -11, -8, -1, -1, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, -2, -2, -2, 2, -3, -3, 0, 0, 0], [0, -3, 0, 0, 0, 0, 0, 2, -9, 2, -4, 1, 4, -2, 0, 0], [0, 0, 0, 0, 0, 0, 0, 3, -11, 11, -3, 6, -2, -4, 0, 0], [0, 0, 0, -4, 0, -2, -5, 0, 0, 0, 0, 0, 0, 0, 6, -5], [0, 0, 0, 0, 0, 0, 0, 3, -9, 9, -3, -5, -1, 6, 0, 0], [7, 0, 7, 0, 1, 4, -1, 0, 0, 0, 0, 0, 0, 0, 4, 0], [-21, 0, 0, 4, -3, -4, 3, 0, 0, 0, 0, 0, 0, 0, -7, 7], [6, 0, -6, 4, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, -8, 0], [-6, 0, -6, 0, 6, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, -3], [-4, 0, 4, 2, 4, 8, 6, 0, 0, 0, 0, 0, 0, 0, 4, 4], [0, 2, 0, 0, 0, 0, 0, -4, 2, 2, 4, 2, 4, 0, 0, 0], [8, 0, -7, 5, 0, 2, -7, 0, 0, 0, 0, 0, 0, 0, 2, -2], [-4, 0, 11, -1, -2, 2, 3, 0, 0, 0, 0, 0, 0, 0, 4, 4], [-1, 0, 1, -13, 0, 12, 2, 0, 0, 0, 0, 0, 0, 0, 1, 2], [0, 0, 0, 0, 0, 0, 0, -4, 9, -9, 4, -4, 4, 0, 0, 0], [0, -6, 0, 0, 0, 0, 0, 1, 17, 17, -5, 3, 3, 0, 0, 0], [0, -4, 0, 0, 0, 0, 0, 1, 7, 1, 2, -6, -2, 3, 0, 0], [15, 0, -6, 0, -7, 6, 1, 0, 0, 0, 0, 0, 0, 0, -1, 1], [0, -5, 0, 0, 0, 0, 0, 1, -3, -1, -8, -3, -8, 7, 0, 0], [1, 0, 1, 0, 8, 1, -5, 0, 0, 0, 0, 0, 0, 0, 1, -3], [0, -10, 0, 0, 0, 0, 0, 0, -6, 0, -6, -4, 6, -6, 0, 0], [0, 0, 0, 0, 0, 0, 0, -6, 0, 0, 6, 2, -2, 0, 0, 0], [9, 0, 0, 3, 12, -3, -12, 0, 0, 0, 0, 0, 0, 0, 9, -9], [15, 0, 15, 0, -1, -2, 1, 0, 0, 0, 0, 0, 0, 0, -2, 0], [4, 0, 4, 0, -6, -6, 5, 0, 0, 0, 0, 0, 0, 0, -6, 1], [8, 0, -8, 8, 0, -8, -2, 0, 0, 0, 0, 0, 0, 0, 0, -2], [0, 0, 0, 0, 0, 0, 0, 6, -8, 8, -6, 7, 3, -10, 0, 0], [0, -14, 0, 0, 0, 0, 0, 4, -17, -17, -10, -3, -3, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, 1, 5, 9, 9, 5, 9, -10, 0, 0], [17, 0, -17, 0, 0, -2, 1, 0, 0, 0, 0, 0, 0, 0, 2, 1], [-11, 0, -11, 0, -6, -2, -2, 0, 0, 0, 0, 0, 0, 0, -2, 8], [2, 0, -3, 1, 10, 8, -1, 0, 0, 0, 0, 0, 0, 0, -2, -2], [-9, 0, 9, -11, 5, 2, 4, 0, 0, 0, 0, 0, 0, 0, 7, -7], [0, -2, 0, 0, 0, 0, 0, 4, -11, -11, 2, -3, -3, 0, 0, 0], [4, 0, -4, -8, 0, -2, -4, 0, 0, 0, 0, 0, 0, 0, 10, -4], [-14, 0, -14, 0, 5, 7, -3, 0, 0, 0, 0, 0, 0, 0, 7, -2], [-2, 0, 2, 10, 0, -6, -8, 0, 0, 0, 0, 0, 0, 0, -4, -8], [0, 0, 0, 0, 0, 0, 0, 4, 3, -3, -4, -1, -8, 9, 0, 0], [0, -9, 0, 0, 0, 0, 0, 3, 10, 10, -6, -5, -5, 0, 0, 0], [0, -4, 0, 0, 0, 0, 0, 0, 4, 0, -8, 4, 8, -8, 0, 0], [0, 9, 0, 0, 0, 0, 0, -9, -3, -6, 6, -3, 6, 3, 0, 0], [0, 0, 0, 0, 0, 0, 0, -8, 8, -8, 6, -6, -6, -2, 0, 0], [-17, 0, -1, -6, -2, 7, 1, 0, 0, 0, 0, 0, 0, 0, 5, -5], [-1, 0, 1, -4, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 3, -3], [1, 0, 1, 4, 2, 1, 3, 0, 0, 0, 0, 0, 0, 0, -1, -1], [4, 0, -8, 9, -2, -6, 5, 0, 0, 0, 0, 0, 0, 0, -4, -4], [-8, 0, -8, 0, -3, -1, 9, 0, 0, 0, 0, 0, 0, 0, -1, -6], [-1, 0, 1, 10, 0, -7, -5, 0, 0, 0, 0, 0, 0, 0, -3, -5], [-2, 0, -11, -1, 8, 10, 1, 0, 0, 0, 0, 0, 0, 0, 2, 2], [0, -4, 0, 0, 0, 0, 0, -3, 16, -3, -2, -2, 2, -5, 0, 0], [0, -8, 0, 0, 0, 0, 0, 8, -6, -6, 0, 3, 3, 0, 0, 0], [-1, 0, -1, 0, 6, -5, -3, 0, 0, 0, 0, 0, 0, 0, -5, -3], [19, 0, 2, -2, -4, 0, 6, 0, 0, 0, 0, 0, 0, 0, -4, 4], [-2, 0, 11, 6, 8, 10, 8, 0, 0, 0, 0, 0, 0, 0, 2, 2], [0, 3, 0, 0, 0, 0, 0, 1, 6, 1, 10, -7, -10, 11, 0, 0], [0, -1, 0, 0, 0, 0, 0, -1, 0, 34, -1, 0, -1, 2, 0, 0], [0, -8, 0, 0, 0, 0, 0, 1, 1, -8, -7, 1, -7, 6, 0, 0], [6, 0, 5, 5, 3, -3, -1, 0, 0, 0, 0, 0, 0, 0, -6, -6], [0, 13, 0, 0, 0, 0, 0, -4, -4, -4, 9, -1, -1, 0, 0, 0], [9, 0, -1, 6, 4, -5, -5, 0, 0, 0, 0, 0, 0, 0, -1, 1], [9, 0, -9, -9, 0, 4, 2, 0, 0, 0, 0, 0, 0, 0, 5, 2], [0, 13, 0, 0, 0, 0, 0, -15, -4, -4, 9, -4, 9, 6, 0, 0], [0, 0, 0, 0, 0, 0, 0, -9, 1, -1, 9, 1, 0, -1, 0, 0], [0, 0, 0, 0, 0, 0, 0, -3, 5, -5, 3, -3, -1, 4, 0, 0], [-9, 0, 9, -2, 0, -3, -1, 0, 0, 0, 0, 0, 0, 0, 5, -1], [0, 10, 0, 0, 0, 0, 0, -5, -3, -7, 7, -3, 7, -2, 0, 0], [-1, 0, -10, 7, -10, -9, 8, 0, 0, 0, 0, 0, 0, 0, 1, 1], [0, -6, 0, 0, 0, 0, 0, -2, -17, -2, -7, 1, 7, -9, 0, 0], [0, -2, 0, 0, 0, 0, 0, 11, -5, 2, -7, -5, -7, -4, 0, 0], [6, 0, -6, -7, -7, 13, 1, 0, 0, 0, 0, 0, 0, 0, 6, -6], [6, 0, -6, -12, 0, 6, -10, 0, 0, 0, 0, 0, 0, 0, 6, -10], [0, -2, 0, 0, 0, 0, 0, 2, -11, 14, -13, -11, -13, 11, 0, 0], [0, 2, 0, 0, 0, 0, 0, 12, -1, -21, 1, -1, 1, -13, 0, 0], [0, 14, 0, 0, 0, 0, 0, -11, -7, -7, 3, 5, 5, 0, 0, 0], [-6, 0, 0, 5, -6, 0, 11, 0, 0, 0, 0, 0, 0, 0, 6, 6], [4, 0, -9, 4, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, -4, -4], [-8, 0, -8, 0, -9, -4, 13, 0, 0, 0, 0, 0, 0, 0, -4, -4], [0, -5, 0, 0, 0, 0, 0, 1, 9, 9, -4, 5, 5, 0, 0, 0], [4, 0, 4, 0, 2, 2, -4, 0, 0, 0, 0, 0, 0, 0, 2, 2], [0, 11, 0, 0, 0, 0, 0, -11, -20, -11, 5, 6, -5, -6, 0, 0], [18, 0, 18, 0, 0, 10, 4, 0, 0, 0, 0, 0, 0, 0, 10, -4], [0, 4, 0, 0, 0, 0, 0, 6, 6, 6, 10, 10, 10, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, -9, 12, -5, 13, 12, 13, -4, 0, 0], [0, 14, 0, 0, 0, 0, 0, -3, 17, -3, 11, 3, -11, 8, 0, 0], [0, 6, 0, 0, 0, 0, 0, -6, -28, -28, 0, -1, -1, 0, 0, 0], [-13, 0, -13, 0, -6, 4, -1, 0, 0, 0, 0, 0, 0, 0, 4, 7], [0, 0, 0, 0, 0, 0, 0, 4, -30, 30, -4, -4, -2, 6, 0, 0], [-6, 0, 6, -8, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0], [0, 0, 0, 0, 0, 0, 0, 2, -27, 27, -2, -1, -2, 3, 0, 0], [0, 1, 0, 0, 0, 0, 0, 9, 8, 8, 10, -3, -3, 0, 0, 0], [7, 0, 1, -3, 9, 2, -8, 0, 0, 0, 0, 0, 0, 0, 11, -11], [5, 0, -5, 7, 0, 7, 4, 0, 0, 0, 0, 0, 0, 0, -14, 4], [0, 0, 0, 0, 0, 0, 0, 0, -2, 2, 0, -3, -11, 14, 0, 0], [6, 0, -18, 1, -7, -13, -5, 0, 0, 0, 0, 0, 0, 0, -6, -6], [5, 0, -4, 7, -2, -3, -2, 0, 0, 0, 0, 0, 0, 0, -5, 5], [-26, 0, 2, -2, -4, 0, 6, 0, 0, 0, 0, 0, 0, 0, -4, 4], [0, 10, 0, 0, 0, 0, 0, -8, 7, -8, -1, 11, 1, -9, 0, 0], [0, 0, 7, -2, -13, -13, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [24, 0, 24, 0, -11, -13, 11, 0, 0, 0, 0, 0, 0, 0, -13, 0], [0, -17, 0, 0, 0, 0, 0, 10, 12, 12, -7, -1, -1, 0, 0, 0], [0, -5, 0, 0, 0, 0, 0, 6, 16, 6, -5, 0, 5, 1, 0, 0], [0, 4, 0, 0, 0, 0, 0, 1, 7, 13, 11, 7, 11, -12, 0, 0], [15, 0, -15, 19, 0, -4, -4, 0, 0, 0, 0, 0, 0, 0, -15, -4], [-5, 0, -1, -2, 14, 19, 3, 0, 0, 0, 0, 0, 0, 0, 5, 5], [0, 7, 0, 0, 0, 0, 0, -15, 5, 20, 12, 5, 12, 3, 0, 0], [0, -6, 0, 0, 0, 0, 0, 2, 18, 2, -16, 10, 16, -14, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 9, -9, 0, -7, 7, 0, 0, 0], [25, 0, 3, 2, 17, -5, -14, 0, 0, 0, 0, 0, 0, 0, 12, -12], [0, -1, 0, 0, 0, 0, 0, 2, -25, 2, 10, -11, -10, 12, 0, 0], [-19, 0, 19, -14, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 5, 1], [0, -14, 0, 0, 0, 0, 0, 8, 0, 0, -6, 0, 0, 0, 0, 0], [0, 9, 0, 0, 0, 0, 0, 3, 4, 4, 12, -5, -5, 0, 0, 0], [-20, 0, -20, 0, -10, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -19, 0, 0, 0, 0, 0, 8, 1, 8, -6, -13, 6, 2, 0, 0], [-9, 0, -10, 13, 3, -3, -13, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-18, 0, 18, 8, 0, -8, -4, 0, 0, 0, 0, 0, 0, 0, 0, -4], [16, 0, 16, 0, 17, -4, -5, 0, 0, 0, 0, 0, 0, 0, -4, -12], [5, 0, -5, -7, 0, -7, -9, 0, 0, 0, 0, 0, 0, 0, 14, -9], [0, 0, 0, 0, 0, 0, 0, 4, 5, -5, -4, 2, -12, 10, 0, 0], [0, 14, 0, 0, 0, 0, 0, -5, 3, 3, 9, 3, 3, 0, 0, 0], [0, -14, 0, 0, 0, 0, 0, 7, -3, -22, -17, -3, -17, 10, 0, 0], [0, 0, 0, 0, 0, 0, 0, 4, 19, -19, -4, -1, 5, -4, 0, 0], [4, 0, 18, -2, -6, -10, -6, 0, 0, 0, 0, 0, 0, 0, -4, -4], [-7, 0, -7, 0, 18, 5, -11, 0, 0, 0, 0, 0, 0, 0, 5, -7], [-1, 0, 37, 2, -3, -2, 3, 0, 0, 0, 0, 0, 0, 0, 1, 1], [0, -13, 0, 0, 0, 0, 0, 2, 10, 2, -6, -7, 6, -4, 0, 0], [6, 0, -29, 4, 4, -2, -2, 0, 0, 0, 0, 0, 0, 0, -6, -6], [0, -23, 0, 0, 0, 0, 0, 12, -2, -2, -11, -13, -13, 0, 0, 0], [-1, 0, -1, 0, 23, 8, -17, 0, 0, 0, 0, 0, 0, 0, 8, -6], [36, 0, 2, -2, -6, 0, 8, 0, 0, 0, 0, 0, 0, 0, -6, 6], [16, 0, -16, -10, 0, 10, 2, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, 0, 0, 0, 0, 0, 0, -4, 11, 15, 11, 11, 11, -7, 0, 0], [0, 0, 0, 0, 0, 0, 0, 6, 2, -2, -6, -9, -7, 16, 0, 0], [0, -10, 0, 0, 0, 0, 0, 6, -3, -3, -4, -1, -1, 0, 0, 0], [12, 0, 12, 0, 15, -3, -5, 0, 0, 0, 0, 0, 0, 0, -3, -10], [0, -8, 0, 0, 0, 0, 0, 9, -15, -15, 1, -11, -11, 0, 0, 0], [0, -8, 0, 0, 0, 0, 0, 11, -1, 7, -9, -1, -9, -2, 0, 0], [6, 0, -6, -6, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, -8, 0], [0, 4, 0, 0, 0, 0, 0, -4, -7, -7, 0, -4, -4, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 4, -8, 8, -4, -4, 14, -10, 0, 0], [0, 0, 0, 0, 0, 0, 0, 4, 1, -1, -4, -9, 1, 8, 0, 0], [5, 0, -5, -5, 0, 4, -14, 0, 0, 0, 0, 0, 0, 0, 1, -14], [0, -14, 0, 0, 0, 0, 0, 10, -1, 3, -15, -1, -15, 5, 0, 0], [-6, 0, -6, -10, -12, -6, -4, 0, 0, 0, 0, 0, 0, 0, 6, 6], [0, -18, 0, 0, 0, 0, 0, 2, -34, 2, -8, -10, 8, -6, 0, 0], [0, 0, 0, 0, 0, 0, 0, 3, 1, -1, -3, 18, 4, -22, 0, 0], [0, -4, 0, 0, 0, 0, 0, -12, 9, 20, 5, 9, 5, 7, 0, 0], [10, 0, -6, 6, 2, 0, -8, 0, 0, 0, 0, 0, 0, 0, 2, -2], [-29, 0, 29, -2, 0, -4, 5, 0, 0, 0, 0, 0, 0, 0, 6, 5], [0, 0, 0, 0, 0, 0, 0, -1, 3, -3, 1, 8, 7, -15, 0, 0], [0, 0, 0, 0, 0, 0, 0, 7, 11, 11, 7, 9, 9, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, 2, 4, 4, 6, -8, -8, 0, 0, 0], [2, 0, -2, 8, 0, -12, -10, 0, 0, 0, 0, 0, 0, 0, 4, -10], [28, 0, 28, 0, -5, -14, 6, 0, 0, 0, 0, 0, 0, 0, -14, -1], [0, 0, -14, -9, -3, -3, -9, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-14, 0, 14, -2, 0, -5, -4, 0, 0, 0, 0, 0, 0, 0, 7, -4], [1, 0, 11, 2, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, -1, -1], [0, -8, 0, 0, 0, 0, 0, 4, 10, 10, -4, 9, 9, 0, 0, 0], [0, 12, 0, 0, 0, 0, 0, -2, 4, -2, -4, 16, 4, -6, 0, 0], [-9, 0, 4, -7, 0, 3, 4, 0, 0, 0, 0, 0, 0, 0, 3, -3], [-5, 0, 5, 3, 0, -7, -9, 0, 0, 0, 0, 0, 0, 0, 4, -9], [0, 0, 0, 0, 0, 0, 0, 17, -3, 3, -17, 7, -10, 3, 0, 0], [0, 21, 0, 0, 0, 0, 0, -9, 2, -9, 11, 10, -11, 2, 0, 0], [0, 0, 16, -12, 14, 14, -12, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, 0, 2, 0, 16, 1, -17, 0, 0, 0, 0, 0, 0, 0, 1, 1], [0, -8, 0, 0, 0, 0, 0, 8, -18, -18, 0, -18, -18, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 6, -16, 16, -6, 14, -6, -8, 0, 0], [-7, 0, 7, -5, 0, -5, -9, 0, 0, 0, 0, 0, 0, 0, 10, -9], [-9, 0, -9, 0, -10, 0, 13, 0, 0, 0, 0, 0, 0, 0, 0, -3], [-3, 0, 6, -10, 18, 4, -12, 0, 0, 0, 0, 0, 0, 0, 22, -22], [-28, 0, -28, 0, 9, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, -5], [0, 0, 0, 0, 0, 0, 0, 11, 0, 0, -11, 16, 2, -18, 0, 0], [14, 0, -14, 10, 0, -11, -6, 0, 0, 0, 0, 0, 0, 0, 1, -6], [4, 0, 33, 3, 0, -4, -1, 0, 0, 0, 0, 0, 0, 0, -4, -4], [15, 0, 1, -10, 10, 9, -9, 0, 0, 0, 0, 0, 0, 0, 19, -19], [0, 10, 0, 0, 0, 0, 0, 0, 0, -2, 10, 0, 10, -10, 0, 0], [0, 1, 0, 0, 0, 0, 0, 2, 0, 48, 1, 0, 1, -3, 0, 0], [13, 0, 13, 0, 4, -8, -2, 0, 0, 0, 0, 0, 0, 0, -8, -2], [0, -2, 0, 0, 0, 0, 0, 12, -17, 12, -5, 3, 5, 7, 0, 0], [0, -2, 0, 0, 0, 0, 0, 18, -6, -8, -8, -6, -8, -10, 0, 0], [-1, 0, -22, -12, -1, 0, -11, 0, 0, 0, 0, 0, 0, 0, 1, 1], [0, 9, 0, 0, 0, 0, 0, 7, -10, 7, 0, 9, 0, 7, 0, 0], [-3, 0, -3, 0, -6, -6, -6, 0, 0, 0, 0, 0, 0, 0, -6, 12], [0, 0, 0, 0, 0, 0, 0, -15, 9, -9, 15, -12, -3, 15, 0, 0], [0, 0, 0, 0, 0, 0, 0, 23, -11, 11, -23, 13, -12, -1, 0, 0], [13, 0, 0, -12, 8, 12, -8, 0, 0, 0, 0, 0, 0, 0, 20, -20], [0, -2, 0, 0, 0, 0, 0, 5, 1, 5, -6, 4, 6, -1, 0, 0], [2, 0, -2, 0, 0, -5, -6, 0, 0, 0, 0, 0, 0, 0, 5, -6], [0, 31, 0, 0, 0, 0, 0, -11, 5, 5, 20, 13, 13, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -2, 7, -27, 7, 7, 7, -5, 0, 0], [12, 0, -12, -1, 0, -11, 2, 0, 0, 0, 0, 0, 0, 0, 12, 2], [6, 0, -4, 13, -20, -26, 7, 0, 0, 0, 0, 0, 0, 0, -6, -6], [0, 19, 0, 0, 0, 0, 0, -11, -6, -1, 13, -6, 13, -2, 0, 0], [5, 0, -5, -5, 0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 0, -5], [-19, 0, -19, 0, 12, 3, -6, 0, 0, 0, 0, 0, 0, 0, 3, -6], [0, 0, 0, 0, 0, 0, 0, -13, 25, -25, 13, 11, 14, -25, 0, 0], [0, -24, 0, 0, 0, 0, 0, 19, 21, 21, -5, 1, 1, 0, 0, 0], [16, 0, 2, 4, -24, -6, 26, 0, 0, 0, 0, 0, 0, 0, -30, 30], [0, -12, 0, 0, 0, 0, 0, 4, -4, 4, 0, -12, 0, 4, 0, 0], [11, 0, -7, 6, -3, 1, -4, 0, 0, 0, 0, 0, 0, 0, -2, 2], [8, 0, 8, 0, -11, 9, 17, 0, 0, 0, 0, 0, 0, 0, 9, -6], [0, 13, 0, 0, 0, 0, 0, 5, -13, -13, 18, -1, -1, 0, 0, 0], [-13, 0, -13, 0, 2, 9, -1, 0, 0, 0, 0, 0, 0, 0, 9, -1], [16, 0, -6, 0, 2, 6, -8, 0, 0, 0, 0, 0, 0, 0, 8, -8], [3, 0, -3, 3, 0, -15, -10, 0, 0, 0, 0, 0, 0, 0, 12, -10], [0, -18, 0, 0, 0, 0, 0, 16, 12, 16, -6, 12, -6, -10, 0, 0], [-6, 0, 16, -11, 10, 16, -5, 0, 0, 0, 0, 0, 0, 0, 6, 6], [0, 0, 0, 0, 0, 0, 0, 5, 5, -5, -5, 11, 15, -26, 0, 0], [9, 0, 16, -12, 7, -4, 9, 0, 0, 0, 0, 0, 0, 0, 3, -3], [5, 0, 5, 0, 12, 11, -3, 0, 0, 0, 0, 0, 0, 0, 11, -9], [0, 9, 0, 0, 0, 0, 0, -9, 20, -9, -1, 10, 1, -10, 0, 0], [0, -14, 0, 0, 0, 0, 0, -6, 0, 0, -20, -2, -2, 0, 0, 0], [0, 3, 0, 0, 0, 0, 0, 6, -24, 6, 9, -6, -9, 15, 0, 0], [-7, 0, 12, -10, -21, -14, -3, 0, 0, 0, 0, 0, 0, 0, 7, 7], [0, 0, 0, 0, 0, 0, 0, -1, 37, 37, -1, 3, 3, 0, 0, 0], [-16, 0, 16, 8, 0, -12, 4, 0, 0, 0, 0, 0, 0, 0, 4, 4], [0, 0, 0, 0, 0, 0, 0, 3, 1, -1, -3, 12, 19, -31, 0, 0], [13, 0, 13, 0, 18, 3, -20, 0, 0, 0, 0, 0, 0, 0, 3, 2], [-5, 0, 5, 6, 0, -6, -6, 0, 0, 0, 0, 0, 0, 0, 0, -6], [0, 13, 0, 0, 0, 0, 0, -23, -3, -16, 10, -3, 10, 13, 0, 0], [-2, 0, 20, -13, 12, 14, -11, 0, 0, 0, 0, 0, 0, 0, 2, 2]]
